# Contributing

<!--start-contributing-->

## Guidelines

Contributing to this project should be as easy and transparent as possible, whether it's:

- Reporting a bug
- Discussing the current state of the code
- Submitting a fix
- Proposing new features

## Getting started

Set up the project with `./scripts/setup.sh`.

## GitHub is used for everything

GitHub is used to host code, to track issues and feature requests, as well as accept pull requests.

Pull requests are the best way to propose changes to the codebase.

1. Fork the repo and create your branch from `main`
2. If you've changed something, update the documentation.
3. Make sure your code lints with `./scripts/lint.sh`.
4. Test you contribution.
5. Issue that pull request!

## Report bugs using Github's [issues](https://github.com/superbox-dev/keba_keenergy_api/issues)

GitHub issues are used to track public bugs.
Report a bug by [opening a new issue](https://github.com/superbox-dev/keba_keenergy_api/issues/new/choose);
it's that easy!

## Write bug reports with detail, background, and sample code

**Great Bug Reports** tend to have:

- A quick summary and/or background
- Steps to reproduce
  - Be specific!
  - Give sample code if you can
- What you expected would happen
- What actually happens
- Notes (possibly including why you think this might be happening, or stuff you tried that didn't work)

People *love* thorough bug reports. I'm not even kidding.

## Use a Consistent Coding Style

Use [black](https://github.com/ambv/black) to make sure the code follows the style.

```bash
uv run black .
```

## Test your code modification

To test the code we use [pytest](https://docs.pytest.org):

```bash
uv run pytest -n auto
```

## License

By contributing, you agree that your contributions will be licensed under its [Apache License][license].

[license]: https://github.com/superbox-dev/keba_keenergy/blob/main/LICENSE

<!--end-contributing-->
